@@ -11,10 +11,10 @@
 #include "util/arg_auto_set.h"
 #include "Rev.h"
 
-#define version "3.0.6"
+#define version "3.1.0"
 
-#define REQ_LIBRND_MAJOR 3
-#define REQ_LIBRND_MINOR 2
+#define REQ_LIBRND_MAJOR 4
+#define REQ_LIBRND_MINOR 0
 
 #define TOSTR_(x) #x
 #define TOSTR(x) TOSTR_(x)
@@ -118,7 +118,7 @@ int hook_postarg()
 	char *tmp;
 	const char *libad;
 
-	put("/local/pcb/librnd_template", tmp = str_concat("", TO_STR(LIBRND_PREFIX), "/", get("/local/libarchdir"), "/librnd3/scconfig/template", NULL));
+	put("/local/pcb/librnd_template", tmp = str_concat("", TO_STR(LIBRND_PREFIX), "/", get("/local/libarchdir"), "/librnd4/scconfig/template", NULL));
 	free(tmp);
 
 	/* if librnd is installed at some custom path, we'll need to have a -I on CFLAGS and -L on LDFLAGS */
@@ -147,9 +147,9 @@ static void calc_dialog_deps(void)
 	int buildin, plugin;
 
 	/* TODO: get this from librnd */
-	control = get("/local/pcb/lib_hid_common/controls");
+	control = get("/local/module/lib_hid_common/controls");
 	if (control == NULL) {
-		fprintf(stderr, "librnd configuration error: can't figure how lib_hid_common is configured\n(should be coming from plugin.state as /local/pcb/lib_hid_common/controls)\n");
+		fprintf(stderr, "librnd configuration error: can't figure how lib_hid_common is configured\n(should be coming from plugin.state as /local/module/lib_hid_common/controls)\n");
 		exit(1);
 	}
 	buildin = strcmp(control, "buildin") == 0;
@@ -334,8 +334,8 @@ int hook_generate()
 	printf("=====================\n");
 
 	print_sum_setting("/local/pcb/want_parsgen",   "Regenerating languages with bison & flex");
-	print_sum_setting("/local/pcb/debug",          "Compilation for debugging");
-	print_sum_setting_or("/local/pcb/symbols",     "Include debug symbols", istrue(get("/local/pcb/debug")));
+	print_sum_setting("/local/rnd/debug",          "Compilation for debugging");
+	print_sum_setting_or("/local/rnd/symbols",     "Include debug symbols", istrue(get("/local/rnd/debug")));
 	print_sum_cfg_val("/local/prefix",             "installation prefix (--prefix)");
 	print_sum_cfg_val("/local/confdir",            "configuration directory (--confdir)");
 	print_sum_cfg_val("/local/pcb/dot_pcb_rnd",    ".pcb_rnd config dir under $HOME");
