@@ -399,27 +399,29 @@ int find_destructor(const char *name, int logdepth, int fatal)
 	return 1;
 }
 
-static int test_fattr(const char *name, int logdepth, int fatal, const char *fattr)
+static int test_fattr(const char *name, int logdepth, int fatal,
+	const char *key, const char *fattr, const char *f_spec, int call_testfunc)
 {
 	char path[64];
-	char test_c[256];
+	char test_c[512];
 	const char *test_c_tmp =
 		NL "#include <stdio.h>"
-		NL "static void test1() __attribute__ ((%s));"
-		NL "static void test1()"
+		NL "%s void test1() __attribute__ ((%s));"
+		NL "%s void test1()"
 		NL "{"
 		NL "	puts(\"OK\");"
 		NL "}"
 		NL "int main() {"
-		NL "	puts(\"OK\");"
+		NL "	%s;"
 		NL "	return 0;"
 		NL "}"
 		NL ;
 
 	require("cc/cc", logdepth, fatal);
 
-	sprintf(test_c, test_c_tmp, fattr);
-	sprintf(path, "cc/func_attr/%s/presents", fattr);
+	sprintf(test_c, test_c_tmp, f_spec, fattr, f_spec,
+		(call_testfunc ? "test1()" : "puts(\"OK\")"));
+	sprintf(path, "cc/func_attr/%s/presents", key);
 
 	report("Checking for function attribute %s... ", fattr);
 	logprintf(logdepth, "test_fattr: trying to find %s...\n", fattr);
@@ -436,7 +438,34 @@ static int test_fattr(const char *name, int logdepth, int fatal, const char *fat
 
 int find_fattr_unused(const char *name, int logdepth, int fatal)
 {
-	return test_fattr(name, logdepth, fatal, "unused");
+	return test_fattr(name, logdepth, fatal, "unused", "unused", "static", 0);
+}
+
+int find_fattr_noreturn(const char *name, int logdepth, int fatal)
+{
+	return test_fattr(name, logdepth, fatal, "noreturn", "noreturn", "", 1);
+}
+
+int find_fattr_deprecated(const char *name, int logdepth, int fatal)
+{
+	return test_fattr(name, logdepth, fatal, "deprecated", "depreated", "", 1);
+}
+
+int find_fattr_weak(const char *name, int logdepth, int fatal)
+{
+	return test_fattr(name, logdepth, fatal, "weak", "weak", "", 1);
+}
+
+int find_fattr_visibility_hidden(const char *name, int logdepth, int fatal)
+{
+	return test_fattr(name, logdepth, fatal, "visibility_hidden",
+		"visibility(\"hidden\")", "", 0);
+}
+
+int find_fattr_visibility_default(const char *name, int logdepth, int fatal)
+{
+	return test_fattr(name, logdepth, fatal, "visibility_default",
+		"visibility(\"default\")", "", 1);
 }
 
 static int test_declspec(const char *name, int logdepth, int fatal, const char *dspec)
@@ -747,6 +776,9 @@ static const char *test_host =
 		NL "#include <stdlib.h>"
 		NL "#include <stdio.h>"
 		NL "#include %s"
+		NL "#ifndef RTLD_NOW"
+		NL "#define RTLD_NOW RTLD_LAZY" /* on old BSD and probably on SunOS */
+		NL "#endif"
 		NL "int main() {"
 		NL "	void *handle = NULL;"
 		NL "	void (*func)() = NULL;"
@@ -754,12 +786,12 @@ static const char *test_host =
 		NL
 		NL "	handle = dlopen(\"%s\", RTLD_NOW);"
 		NL "	if (handle == NULL) {"
-		NL "		printf(\"dlopen fails: \", dlerror());"
+		NL "		printf(\"dlopen fails: %%s\", dlerror());"
 		NL "		return 1;"
 		NL "	}"
 		NL "	func = dlsym(handle, \"hello\");"
 		NL "	if (func == NULL) {"
-		NL "		printf(\"dlsym fails: \", dlerror());"
+		NL "		printf(\"dlsym fails: %%s\", dlerror());"
 		NL "		return 1;"
 		NL "	}"
 		NL "	func();"
@@ -798,7 +830,7 @@ static int try_dynlib(int logdepth, const char *cflags, char *concated_ldflags,
 	libname_dyn = libname = (char *)get("sys/ext_dynlib");
 	if ((compile_code(logdepth, test_lib, &oname, NULL, cflags_c, NULL) != 0) ||
 			(compile_file(logdepth, oname, &libname_dyn, NULL, NULL, concated_ldflags) != 0)) {
-			report("FAILED (compiling dynlib)\n");
+			report("('%s': nope) ", concated_ldflags);
 	}
 	else {
 		sprintf(test_host_app, test_host, ld_include, libname_dyn);
@@ -833,6 +865,7 @@ int find_ldflags_dynlib(const char *name, int logdepth, int fatal)
 
 	if (try_dynlib(logdepth, NULL, concat_nodes("-dynamic -shared", "cc/rdynamic", "libs/ldl", NULL), "cc/ldflags_dynlib", "-dynamic -shared", NULL, get("libs/ldl"))) return 0;
 	if (try_dynlib(logdepth, NULL, concat_nodes("-shared",          "cc/rdynamic", "libs/ldl", NULL), "cc/ldflags_dynlib", "-shared",          NULL, get("libs/ldl"))) return 0;
+	if (try_dynlib(logdepth, NULL, concat_nodes("-G",                              "libs/ldl", NULL), "cc/ldflags_dynlib", "-G",               NULL, get("libs/ldl"))) return 0; /* xlc (on AIX) */
 	report("Not found.\n");
 	return 1;
 }
@@ -900,11 +933,13 @@ static int try_dll_or_so(int logdepth, int is_dll, const char *lib_ldflags, cons
 		lib_filename = file_name(libname);
 		lib_dirname = dir_name(libname);
 
+		len = strlen(lib_filename) - strlen(libname_ext);
 		if (!is_dll) {
-			len = strlen(lib_filename) - strlen(libname_ext);
 			for (ii=3; ii<len; ++ii)
 				lib_filename[ii-3] = lib_filename[ii];
 			lib_filename[len-3] = 0;
+		} else {
+			lib_filename[len] = 0;
 		}
 
 		app_ldflags_new = str_concat("", "-L", lib_dirname, " -l", lib_filename,
@@ -1062,16 +1097,34 @@ int find_alloca(const char *name, int logdepth, int fatal)
 }
 
 
-int find__exit(const char *name, int logdepth, int fatal)
+static int find__exit_(const char *inc, int logdepth, int fatal)
 {
-	const char *test_c =
+	const char *test_c_ =
 		NL "#include <stdio.h>"
+		NL "%s"
 		NL "int main() {"
 		NL "	_exit(0);"
 		NL "	puts(\"BAD\");"
 		NL "	return 0;"
 		NL "}"
 		NL ;
+	char test_c[256];
+
+	sprintf(test_c, test_c_, inc); /* safe because called only with a few hardwired inc values */
+
+	if (try_flags_inv(logdepth, NULL, test_c, NULL, NULL, "BAD")) {
+		put("cc/_exit/presents", strue);
+		put("cc/_exit/includes", inc);
+		report("found\n");
+		return 0;
+	}
+
+	return 1;
+}
+
+int find__exit(const char *name, int logdepth, int fatal)
+{
+	const char **i, *incs[] = {"#include <unistd.h>", NULL};
 
 	require("cc/cc", logdepth, fatal);
 
@@ -1079,11 +1132,9 @@ int find__exit(const char *name, int logdepth, int fatal)
 	logprintf(logdepth, "find__exit: trying to find _exit()...\n");
 	logdepth++;
 
-	if (try_flags_inv(logdepth, NULL, test_c, NULL, NULL, "BAD")) {
-		put("cc/_exit/presents", strue);
-		report("found\n");
-		return 0;
-	}
+	for(i = incs; *i != NULL; i++)
+		if (find__exit_(*i, logdepth, fatal) == 0)
+			return 0;
 
 	put("cc/_exit/presents", sfalse);
 	report("Not found.\n");
