@@ -92,6 +92,7 @@ int find_fs_readdir(const char *name, int logdepth, int fatal)
 	char *test_c =
 		NL "#include <stdlib.h>"
 		NL "#include <stdio.h>"
+		NL "#include <string.h>"
 		NL "int main() {"
 		NL "	DIR *dirp;"
 		NL "	struct dirent *dp;"
@@ -132,7 +133,6 @@ int find_fs_findnextfile(const char *name, int logdepth, int fatal)
 	char *test_c =
 		NL "#include <stdlib.h>"
 		NL "#include <stdio.h>"
-		NL "#include <windows.h>"
 		NL "int main(int argc, char *argv[]) {"
 		NL "	WIN32_FIND_DATA fd;"
 		NL "	HANDLE h;"
@@ -155,7 +155,7 @@ int find_fs_findnextfile(const char *name, int logdepth, int fatal)
 	logprintf(logdepth, "find_fs_findnextfile: trying to find FindNextFile...\n");
 	logdepth++;
 
-	if (try_icl(logdepth, "libs/fs/findnextfile", test_c, NULL, NULL, NULL)) return 0;
+	if (try_icl(logdepth, "libs/fs/findnextfile", test_c, "#include <windows.h>", NULL, NULL)) return 0;
 	return try_fail(logdepth, "libs/fs/findnextfile");
 }
 
@@ -397,6 +397,7 @@ int find_fs_getcwd(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
 		NL "#include <unistd.h>"
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	char b[1024];"
 		NL "	if (getcwd(b, sizeof(b)) != NULL)"
@@ -419,6 +420,7 @@ int find_fs__getcwd(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
 		NL "#include <stdlib.h>"
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	char b[1024];"
 		NL "	if (_getcwd(b, sizeof(b)) != NULL)"
@@ -442,6 +444,7 @@ int find_fs_getwd(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
 		NL "#include <unistd.h>"
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	char b[8192];"
 		NL "	if (getwd(b) != NULL)"
@@ -576,6 +579,83 @@ int find_fs__mkdir(const char *name, int logdepth, int fatal)
 	return try_fail(logdepth, "libs/fs/_mkdir");
 }
 
+static int find_utime_impl(const char *name, int logdepth, int fatal,
+	const char* key, const char* funcname, const char* typename)
+{
+	char test_c[1024+4096];
+	const char *test_c_templ =
+		NL "void puts_OK();"
+		NL "int main(int argc, char* argv[])"
+		NL "{"
+		NL "	struct %s buf;"
+		NL "	buf.actime = buf.modtime = 1610958044;"
+		NL "	if (%s(\"%s\", &buf) == 0)"
+		NL "		puts_OK();"
+		NL "	return 0;"
+		NL "}"
+		NL "#include <stdio.h>"
+		NL "void puts_OK()"
+		NL "{"
+		NL "	puts(\"OK\");"
+		NL "}"
+		NL;
+
+	const char* includes[] =
+	{
+		/* *NIX */
+		"#include <sys/types.h>\n#include <utime.h>",
+
+		/* windoz */
+		"#include <sys/utime.h>",
+
+		NULL
+	};
+	const char** inc;
+	char* tmpf;
+
+	tmpf = tempfile_new(".txt");
+	sprintf(test_c, test_c_templ, typename, funcname, tmpf);
+
+	require("cc/cc", logdepth, fatal);
+
+	report("Checking for %s... ", funcname);
+	logprintf(logdepth, "find_fs_%s: trying to find %s()...\n", funcname, funcname);
+	logdepth++;
+
+	for (inc=includes; *inc; ++inc)
+	{
+		if (try_icl(logdepth, key, test_c, *inc, NULL, NULL))
+		{
+			unlink(tmpf);
+			free(tmpf);
+			return 0;
+		}
+	}
+
+	unlink(tmpf);
+	free(tmpf);
+
+	return try_fail(logdepth, key);
+}
+
+int find_fs_utime(const char *name, int logdepth, int fatal)
+{
+	return find_utime_impl(name, logdepth, fatal,
+		"libs/fs/utime", "utime", "utimbuf");
+}
+
+int find_fs__utime(const char *name, int logdepth, int fatal)
+{
+	return find_utime_impl(name, logdepth, fatal,
+		"libs/fs/_utime", "_utime", "_utimbuf");
+}
+
+int find_fs__utime64(const char *name, int logdepth, int fatal)
+{
+	return find_utime_impl(name, logdepth, fatal,
+		"libs/fs/_utime64", "_utime64", "__utimbuf64");
+}
+
 int find_fs_mkdtemp(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
