@@ -82,6 +82,7 @@ int find_xinerama(const char *name, int logdepth, int fatal)
 	const char *node = "libs/gui/xinerama";
 	char **cflags,  *cflags_arr[]  = {"", NULL};
 	char **ldflags, *ldflags_arr[] = {"-lXinerama", NULL};
+	char **incs, *incs_arr[] = {"#include <X11/extensions/Xinerama.h>", "", NULL};
 	const char *xincludes, *xcflags, *xldflags;
 
 	if (require("cc/cc", logdepth, fatal))
@@ -100,8 +101,10 @@ int find_xinerama(const char *name, int logdepth, int fatal)
 
 	for(cflags = cflags_arr; *cflags != NULL; cflags++) {
 		for(ldflags = ldflags_arr; *ldflags != NULL; ldflags++) {
-			if (try_icl_with_deps(logdepth, node, test_c, NULL, *cflags, *ldflags, xincludes, xcflags, xldflags, 0) != 0) {
-				return 0;
+			for(incs = incs_arr; *incs != NULL; incs++) {
+				if (try_icl_with_deps(logdepth, node, test_c, *incs, *cflags, *ldflags, xincludes, xcflags, xldflags, 0) != 0) {
+					return 0;
+				}
 			}
 		}
 	}
@@ -320,3 +323,40 @@ int find_xpm(const char *name, int logdepth, int fatal)
 	}
 	return try_fail(logdepth, node);
 }
+
+int find_keysymtoucs4(const char *name, int logdepth, int fatal)
+{
+	const char *test_c =
+		NL "#include <stdio.h>"
+		NL "#include <X11/Xlib.h>"
+		NL "extern unsigned int KeySymToUcs4(KeySym keysym);"
+		NL "int main()"
+		NL "{"
+		NL "	if (KeySymToUcs4(32) == 32)"
+		NL "		puts(\"OK\");"
+		NL "	return 0;"
+		NL "}"
+		NL;
+	const char *node = "libs/gui/keysymtoucs4";
+	const char *xincludes, *xcflags, *xldflags;
+
+	if (require("cc/cc", logdepth, fatal))
+		return 1;
+
+	if (require("libs/gui/xopendisplay/*", logdepth, fatal))
+		return 1;
+
+	xincludes = get("libs/gui/xopendisplay/includes");
+	xcflags = get("libs/gui/xopendisplay/cflags");
+	xldflags = get("libs/gui/xopendisplay/ldflags");
+
+	report("Checking for KeySymToUcs4... ");
+	logprintf(logdepth, "find_KeySymToUcs4:\n");
+	logdepth++;
+
+	/* This should be standard X11 call, but not published so better test */
+	if (try_icl_with_deps(logdepth, node, test_c, NULL, NULL, NULL, xincludes, xcflags, xldflags, 1) != 0)
+		return 0;
+
+	return try_fail(logdepth, node);
+}
