@@ -1,14 +1,14 @@
 #include "config.h"
 #include <librnd/core/conf.h>
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include <librnd/core/conf_hid.h>
 #include <genvector/gds_char.h>
 #include <genht/htpp.h>
 #include <genht/hash.h>
 
 /* Required for win32 path hack: */
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid_init.h>
 
 conf_core_t conf_core;
 
@@ -64,8 +64,6 @@ void pcb_conf_core_postproc(void)
 	htpp_entry_t *e;
 
 	conf_clamp_to(RND_CFT_COORD, conf_core.design.line_thickness, PCB_MIN_THICKNESS, PCB_MAX_THICKNESS, RND_MIL_TO_COORD(10));
-	rnd_conf_force_set_bool(conf_core.rc.have_regex, 1);
-	rnd_conf_ro("rc/have_regex");
 
 	rnd_conf_force_set_str(conf_core.rc.path.prefix, PCB_PREFIX);   rnd_conf_ro("rc/path/prefix");
 	rnd_conf_force_set_str(conf_core.rc.path.lib, PCBLIBDIR);       rnd_conf_ro("rc/path/lib");
@@ -79,7 +77,7 @@ void pcb_conf_core_postproc(void)
 	}
 }
 
-static void conf_legacy_chg(rnd_conf_native_t *ndst, int arr_idx)
+static void conf_legacy_chg(rnd_conf_native_t *ndst, int arr_idx, void *user_data)
 {
  /* check if a legacy nde changes so we need to update a new node */
 	rnd_conf_native_t *nlegacy;
