@@ -81,7 +81,7 @@ typedef struct {
 		RND_CFT_BOOLEAN live_routing;          /* autorouter shows tracks in progress */
 
 		/* Keep it here instead of the router plugin: more than one router plugin may share these */
-		RND_CFT_BOOLEAN beep_when_finished;    /* flag if a signal should be produced when searching of  connections is done */
+		RND_CFT_BOOLEAN beep_when_finished;    /* onsolete: not used */
 
 		RND_CFT_INTEGER undo_warning_size;     /* warn the user when undo list exceeds this amount of kilobytes in memory */
 
@@ -138,7 +138,6 @@ typedef struct {
 		RND_CFT_STRING web_browser;            /* command line to a web browser (useful for accessing external resources, e.g. order pcb web services) */
 
 		/***** automatically set (in postproc) *****/
-		RND_CFT_BOOLEAN have_regex;            /* whether we have regex compiled in */
 		struct {
 			RND_CFT_STRING prefix;               /* e.g. /usr/local */
 			RND_CFT_STRING lib;                  /* e.g. /usr/lib/pcb-rnd */
