@@ -4,7 +4,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996 Thomas Nau
- *  Copyright (C) 2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2020,2022 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "config.h"
 
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include "brave.h"
 
@@ -42,14 +42,14 @@
 #include "search.h"
 #include "polygon.h"
 #include <librnd/core/actions.h>
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/poly/offset.h>
 #include "find.h"
 #include "undo.h"
 #include "event.h"
 #include "thermal.h"
-#include <librnd/core/grid.h>
+#include <librnd/hid/grid.h>
 
 #include "obj_line_draw.h"
 #include "obj_arc_draw.h"
@@ -60,7 +60,7 @@
 #include "obj_arc_ui.h"
 #include "obj_subc_parent.h"
 
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 
 typedef struct {
 	int x, y;
@@ -68,10 +68,53 @@ typedef struct {
 
 static char crosshair_cookie[] = "crosshair";
 
+static int crosshair_gui_inited = 0;
+
 pcb_crosshair_t pcb_crosshair;  /* information about cursor settings */
 rnd_mark_t pcb_marked;
 pcb_crosshair_note_t pcb_crosshair_note;
 
+/* point cursor is shown when the mouse cursor is over the endpoint of a line */
+#define pointIcon_width  16
+#define pointIcon_height 16
+static unsigned char pointIcon_bits[] = {
+	0x00, 0x00, 0x80, 0x00, 0x80, 0x00, 0x80, 0x00, 0x80, 0x00, 0x00, 0x00, 
+	0x00, 0x00, 0x1e, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x80, 0x00, 
+	0x80, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00};
+#define pointMask_width  16
+#define pointMask_height 16
+static unsigned char pointMask_bits[] = {
+	0xc0, 0x01, 0xc0, 0x01, 0xc0, 0x01, 0xc0, 0x01, 0xc0, 0x01, 0x80, 0x00, 
+	0x1f, 0x7c, 0x3f, 0x7e, 0x1f, 0x7c, 0x80, 0x00, 0xc0, 0x01, 0xc0, 0x01, 
+	0xc0, 0x01, 0xc0, 0x01, 0xc0, 0x01, 0x00, 0x00};
+
+/* need to register a dummy tool for the point cursor because mouse cursors
+   are managed by the tool code */
+static rnd_tool_t pcb_tool_point = {
+	"crosshair-point", NULL, NULL, 0, NULL, RND_TOOL_CURSOR_XBM(pointIcon_bits, pointMask_bits), 0,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	0
+};
+
+static int pcb_tool_point_id = -1;
+
+static void pcb_point_cursor(rnd_bool enable)
+{
+	if ((rnd_gui != NULL) && crosshair_gui_inited) {
+		/* register the tool when first needed */
+		if (pcb_tool_point_id < 0)
+			pcb_tool_point_id = rnd_tool_reg(&pcb_tool_point, crosshair_cookie);
+		rnd_hid_override_mouse_cursor(enable ? pcb_tool_point_id : -1);
+	}
+}
 
 static void thindraw_moved_ps(pcb_pstk_t *ps, rnd_coord_t x, rnd_coord_t y)
 {
@@ -679,7 +722,7 @@ void pcb_xordraw_movecopy(rnd_bool modifier)
 		rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icc", 0, dx, dy);
 }
 
-void pcb_crosshair_attached_clean(rnd_hidlib_t *hidlib)
+void pcb_crosshair_attached_clean(rnd_design_t *hidlib)
 {
 	if (xordraw_cache.pline != NULL)
 		rnd_poly_contour_del(&xordraw_cache.pline);
@@ -688,7 +731,7 @@ void pcb_crosshair_attached_clean(rnd_hidlib_t *hidlib)
 		rnd_polyarea_free(&xordraw_cache.pa);
 }
 
-void pcb_crosshair_draw_attached(rnd_hidlib_t *hidlib, rnd_bool inhibit_drawing_mode)
+void pcb_crosshair_draw_attached(rnd_design_t *hidlib, rnd_bool inhibit_drawing_mode)
 {
 	if (!inhibit_drawing_mode) {
 		rnd_render->set_drawing_mode(rnd_gui, RND_HID_COMP_RESET, 1, NULL);
@@ -713,7 +756,7 @@ void pcb_crosshair_draw_attached(rnd_hidlib_t *hidlib, rnd_bool inhibit_drawing_
 		rnd_render->set_drawing_mode(rnd_gui, RND_HID_COMP_FLUSH, 1, NULL);
 }
 
-void pcb_crosshair_draw_marks(rnd_hidlib_t *hidlib, rnd_bool inhibit_drawing_mode)
+void pcb_crosshair_draw_marks(rnd_design_t *hidlib, rnd_bool inhibit_drawing_mode)
 {
 	rnd_coord_t ms = conf_core.appearance.mark_size, ms2 = ms / 2;
 
@@ -907,7 +950,7 @@ static void check_snap_offgrid_line(pcb_board_t *pcb, struct snap_data *snap_dat
  */
 void pcb_crosshair_grid_fit(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 {
-	rnd_hidlib_t *hidlib = &pcb->hidlib;
+	rnd_design_t *hidlib = &pcb->hidlib;
 	rnd_coord_t nearest_grid_x, nearest_grid_y, oldx, oldy;
 	void *ptr1, *ptr2, *ptr3;
 	struct snap_data snap_data;
@@ -915,8 +958,8 @@ void pcb_crosshair_grid_fit(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 
 	oldx = pcb_crosshair.X;
 	oldy = pcb_crosshair.Y;
-	pcb->hidlib.ch_x = pcb_crosshair.X = RND_CLAMP(X, -pcb->hidlib.size_x/2, pcb->hidlib.size_x*3/2);
-	pcb->hidlib.ch_y = pcb_crosshair.Y = RND_CLAMP(Y, -pcb->hidlib.size_y/2, pcb->hidlib.size_y*3/2);
+	pcb->hidlib.ch_x = pcb_crosshair.X = RND_CLAMP(X, pcb->hidlib.dwg.X1 - rnd_dwg_get_size_x(&pcb->hidlib)/2, pcb->hidlib.dwg.X2 + rnd_dwg_get_size_x(&pcb->hidlib)/2);
+	pcb->hidlib.ch_y = pcb_crosshair.Y = RND_CLAMP(Y, pcb->hidlib.dwg.Y1 - rnd_dwg_get_size_y(&pcb->hidlib)/2, pcb->hidlib.dwg.Y2 + rnd_dwg_get_size_y(&pcb->hidlib)/2);
 
 	nearest_grid_x = rnd_grid_fit(pcb_crosshair.X, pcb->hidlib.grid, pcb->hidlib.grid_ox);
 	nearest_grid_y = rnd_grid_fit(pcb_crosshair.Y, pcb->hidlib.grid, pcb->hidlib.grid_oy);
@@ -1035,14 +1078,10 @@ void pcb_crosshair_grid_fit(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 
 	if (rnd_conf.editor.mode == pcb_crosshair.tool_arrow) {
 		ans = pcb_search_grid_slop(X, Y, PCB_OBJ_LINE_POINT, &ptr1, &ptr2, &ptr3);
-		if (ans == PCB_OBJ_VOID) {
-			if ((rnd_gui != NULL) && (rnd_gui->point_cursor != NULL))
-				rnd_gui->point_cursor(rnd_gui, rnd_false);
-		}
-		else if (!PCB_FLAG_TEST(PCB_FLAG_SELECTED, (pcb_line_t *) ptr2)) {
-			if ((rnd_gui != NULL) && (rnd_gui->point_cursor != NULL))
-				rnd_gui->point_cursor(rnd_gui, rnd_true);
-		}
+		if (ans == PCB_OBJ_VOID)
+			pcb_point_cursor(rnd_false);
+		else if (!PCB_FLAG_TEST(PCB_FLAG_SELECTED, (pcb_line_t *)ptr2))
+			pcb_point_cursor(rnd_true);
 	}
 
 	enfmode  = (rnd_conf.editor.mode == pcb_crosshair.tool_line) && pcb_crosshair.AttachedLine.State != PCB_CH_STATE_FIRST;
@@ -1059,7 +1098,7 @@ void pcb_crosshair_grid_fit(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 		pcb_line_enforce_drc(pcb, thick);
 	}
 
-	rnd_gui->set_crosshair(rnd_gui, pcb_crosshair.X, pcb_crosshair.Y, HID_SC_DO_NOTHING);
+	rnd_gui->set_crosshair(rnd_gui, pcb_crosshair.X, pcb_crosshair.Y, RND_SC_DO_NOTHING);
 }
 
 /* ---------------------------------------------------------------------------
@@ -1108,12 +1147,12 @@ void pcb_center_display(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 	pcb->hidlib.grid = 1;
 	if (pcb_crosshair_move_absolute(pcb, X, Y))
 		rnd_hid_notify_crosshair_change(&pcb->hidlib, rnd_true);
-	rnd_gui->set_crosshair(rnd_gui, pcb_crosshair.X, pcb_crosshair.Y, HID_SC_WARP_POINTER);
+	rnd_gui->set_crosshair(rnd_gui, pcb_crosshair.X, pcb_crosshair.Y, RND_SC_WARP_POINTER);
 	pcb->hidlib.grid = save_grid;
 }
 
 /* allocate GC only when the GUI is already up and running */
-static void pcb_crosshair_gui_init(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void pcb_crosshair_gui_init(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	pcb_crosshair.GC = rnd_hid_make_gc();
 
@@ -1121,6 +1160,8 @@ static void pcb_crosshair_gui_init(rnd_hidlib_t *hidlib, void *user_data, int ar
 	rnd_hid_set_draw_xor(pcb_crosshair.GC, 1);
 	rnd_hid_set_line_cap(pcb_crosshair.GC, rnd_cap_round);
 	rnd_hid_set_line_width(pcb_crosshair.GC, 1);
+
+	crosshair_gui_inited = 1;
 }
 
 /* ---------------------------------------------------------------------------
@@ -1153,6 +1194,7 @@ void pcb_crosshair_uninit(void)
 	if (rnd_render != NULL)
 		rnd_hid_destroy_gc(pcb_crosshair.GC);
 	rnd_event_unbind_allcookie(crosshair_cookie);
+	rnd_tool_unreg_by_cookie(crosshair_cookie);
 }
 
 void pcb_crosshair_set_local_ref(rnd_coord_t X, rnd_coord_t Y, rnd_bool Showing)
@@ -1193,7 +1235,7 @@ typedef struct {
 	int obj, line, box;
 } old_crosshair_t;
 
-void *pcb_crosshair_suspend(rnd_hidlib_t *hl)
+void *pcb_crosshair_suspend(rnd_design_t *hl)
 {
 	old_crosshair_t *buf = malloc(sizeof(old_crosshair_t));
 
@@ -1208,7 +1250,7 @@ void *pcb_crosshair_suspend(rnd_hidlib_t *hl)
 	return buf;
 }
 
-void pcb_crosshair_restore(rnd_hidlib_t *hl, void *susp_data)
+void pcb_crosshair_restore(rnd_design_t *hl, void *susp_data)
 {
 	old_crosshair_t *buf = susp_data;
 
@@ -1222,7 +1264,7 @@ void pcb_crosshair_restore(rnd_hidlib_t *hl, void *susp_data)
 }
 
 
-void pcb_hidlib_crosshair_move_to(rnd_hidlib_t *hl, rnd_coord_t abs_x, rnd_coord_t abs_y, int mouse_mot)
+void pcb_hidlib_crosshair_move_to(rnd_design_t *hl, rnd_coord_t abs_x, rnd_coord_t abs_y, int mouse_mot)
 {
 	if (!mouse_mot) {
 		rnd_hid_notify_crosshair_change(hl, rnd_false);
