@@ -30,7 +30,7 @@
 #include "config.h"
 
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include <librnd/core/math_helper.h>
 #include "board.h"
 #include "data.h"
@@ -40,7 +40,7 @@
 #include <librnd/poly/rtree.h>
 #include "stub_draw.h"
 #include "layer_ui.h"
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include <librnd/core/conf_hid.h>
 #include "funchash_core.h"
 
@@ -1005,7 +1005,7 @@ void pcb_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *ctx, rnd_xform_
 	}
 }
 
-void pcb_expose_preview(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *e)
+void pcb_expose_preview(rnd_hid_t *hid, rnd_hid_expose_ctx_t *e)
 {
 	pcb_output_t save;
 	expose_begin(&save, hid);
@@ -1149,7 +1149,7 @@ void pcb_term_label_invalidate(rnd_coord_t x, rnd_coord_t y, double scale, rnd_b
 
 static const char draw_cookie[] = "core/draw";
 
-static void draw_chg_render_script(rnd_conf_native_t *cfg, int arr_idx)
+static void draw_chg_render_script(rnd_conf_native_t *cfg, int arr_idx, void *user_data)
 {
 	draw_everything_recompile = conf_core.appearance.render_script;
 }
