@@ -31,7 +31,7 @@
 #include "config.h"
 
 #include <librnd/core/compat_misc.h>
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include <librnd/core/actions.h>
 
 
@@ -489,7 +489,7 @@ void *pcb_gfx_destroy(pcb_layer_t *Layer, pcb_gfx_t *gfx)
 void pcb_gfx_rotate90(pcb_gfx_t *gfx, rnd_coord_t X, rnd_coord_t Y, unsigned Number)
 {
 	gfx->rot = rnd_normalize_angle(gfx->rot + Number * 90);
-	TODO("rotate content")
+	gfx->pxm_xformed = pcb_pixmap_alloc_insert_transformed(&pcb_pixmaps, gfx->pxm_neutral, gfx->rot, gfx->xmirror, gfx->ymirror);
 	pcb_gfx_update(gfx);
 	pcb_gfx_bbox(gfx);
 }
@@ -500,7 +500,7 @@ void pcb_gfx_rotate(pcb_layer_t *layer, pcb_gfx_t *gfx, rnd_coord_t X, rnd_coord
 		rnd_r_delete_entry(layer->gfx_tree, (rnd_box_t *) gfx);
 
 	gfx->rot = rnd_normalize_angle(gfx->rot + angle);
-	TODO("rotate content")
+	gfx->pxm_xformed = pcb_pixmap_alloc_insert_transformed(&pcb_pixmaps, gfx->pxm_neutral, gfx->rot, gfx->xmirror, gfx->ymirror);
 	pcb_gfx_update(gfx);
 	pcb_gfx_bbox(gfx);
 
@@ -722,7 +722,7 @@ int gfx_set_resize_by_pixel_dist(pcb_gfx_t *gfx, long pdx, long pdy, rnd_coord_t
 	return 0;
 }
 
-void gfx_set_resize_gui(rnd_hidlib_t *hl, pcb_gfx_t *gfx, rnd_bool allow_x, rnd_bool allow_y)
+void gfx_set_resize_gui(rnd_design_t *hl, pcb_gfx_t *gfx, rnd_bool allow_x, rnd_bool allow_y)
 {
 	char *lens;
 	rnd_coord_t x1, y1, x2, y2;
@@ -905,11 +905,15 @@ void pcb_gfx_draw_(pcb_draw_info_t *info, pcb_gfx_t *gfx, int allow_term_gfx)
 
 
 	if ((gfx->pxm_neutral == NULL) || (rnd_render->draw_pixmap == NULL)) {
-		rnd_render->set_color(pcb_draw_out.fgGC, &conf_core.appearance.color.warn);
-		rnd_hid_set_line_cap(pcb_draw_out.fgGC, rnd_cap_round);
-		rnd_hid_set_line_width(pcb_draw_out.fgGC, RND_MM_TO_COORD(0.1));
-		rnd_render->draw_line(pcb_draw_out.fgGC, gfx->corner[0].X, gfx->corner[0].Y, gfx->corner[2].X, gfx->corner[2].Y);
-		rnd_render->draw_line(pcb_draw_out.fgGC, gfx->corner[1].X, gfx->corner[1].Y, gfx->corner[3].X, gfx->corner[3].Y);
+		if (rnd_render->gui) {
+			/* draw a cross on GUI that can't render pixmap (shouldn't happen);
+			   do not draw anyhting on export */
+			rnd_render->set_color(pcb_draw_out.fgGC, &conf_core.appearance.color.warn);
+			rnd_hid_set_line_cap(pcb_draw_out.fgGC, rnd_cap_round);
+			rnd_hid_set_line_width(pcb_draw_out.fgGC, RND_MM_TO_COORD(0.1));
+			rnd_render->draw_line(pcb_draw_out.fgGC, gfx->corner[0].X, gfx->corner[0].Y, gfx->corner[2].X, gfx->corner[2].Y);
+			rnd_render->draw_line(pcb_draw_out.fgGC, gfx->corner[1].X, gfx->corner[1].Y, gfx->corner[3].X, gfx->corner[3].Y);
+		}
 	}
 	else {
 		rnd_render->draw_pixmap(rnd_render, gfx->cx, gfx->cy, gfx->sx, gfx->sy, gfx->pxm_xformed);
