@@ -29,7 +29,7 @@
 #include <stdlib.h>
 #include <genht/htsp.h>
 
-#include <librnd/core/pixmap.h>
+#include <librnd/hid/pixmap.h>
 #include <librnd/core/error.h>
 #include <librnd/core/math_helper.h>
 #include <librnd/core/compat_misc.h>
@@ -71,7 +71,7 @@ rnd_pixmap_t *pcb_pixmap_insert_neutral_or_free(pcb_pixmap_hash_t *pmhash, rnd_p
 	return pm;
 }
 
-rnd_pixmap_t *pcb_pixmap_insert_neutral_dup(rnd_hidlib_t *hl, pcb_pixmap_hash_t *pmhash, const rnd_pixmap_t *pm)
+rnd_pixmap_t *pcb_pixmap_insert_neutral_dup(rnd_design_t *hl, pcb_pixmap_hash_t *pmhash, const rnd_pixmap_t *pm)
 {
 	rnd_pixmap_t *r;
 
