@@ -40,7 +40,7 @@
 #include "config.h"
 
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include <locale.h>
 #include <dirent.h>
@@ -60,7 +60,7 @@
 #include <librnd/core/actions.h>
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/plugins.h>
-#include <librnd/core/hid_menu.h>
+#include <librnd/hid/hid_menu.h>
 #include "event.h"
 #include <librnd/core/compat_misc.h>
 #include "route_style.h"
@@ -70,7 +70,7 @@
 #include <librnd/core/safe_fs.h>
 #include "plug_footprint.h"
 #include <librnd/core/file_loaded.h>
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include "view.h"
 
 pcb_plug_io_t *pcb_plug_io_chain = NULL;
@@ -78,7 +78,7 @@ int pcb_io_err_inhibit = 0;
 pcb_view_list_t pcb_io_incompat_lst;
 static rnd_bool pcb_io_incompat_lst_enable = rnd_false;
 
-void pcb_plug_io_err(rnd_hidlib_t *hidlib, int res, const char *what, const char *filename)
+void pcb_plug_io_err(rnd_design_t *hidlib, int res, const char *what, const char *filename)
 {
 	if (pcb_io_err_inhibit)
 		return;
@@ -372,9 +372,9 @@ pcb_plug_io_t *pcb_io_find_writer(pcb_plug_iot_t typ, const char *fmt)
 	int len;
 
 	if (fmt == NULL) {
-		if (PCB->hidlib.filename != NULL) { /* have a file name, guess from extension */
-			int fn_len = strlen(PCB->hidlib.filename);
-			const char *end = PCB->hidlib.filename + fn_len;
+		if (PCB->hidlib.loadname != NULL) { /* have a file name, guess from extension */
+			int fn_len = strlen(PCB->hidlib.loadname);
+			const char *end = PCB->hidlib.loadname + fn_len;
 			pcb_plug_io_t *n, *best = NULL;
 			int best_score = 0;
 
@@ -410,7 +410,7 @@ pcb_plug_io_t *pcb_io_find_writer(pcb_plug_iot_t typ, const char *fmt)
 			return NULL;
 		}
 		else {
-			if (PCB->hidlib.filename != NULL)
+			if (PCB->hidlib.loadname != NULL)
 				rnd_message(RND_MSG_WARNING, "Saving a file with unknown format: failed to guess format from file name, falling back to %s as configured in rc/save_final_fallback_fmt\n", fmt);
 		}
 	}
@@ -495,7 +495,7 @@ int pcb_write_padstack(FILE *f, pcb_pstk_proto_t *proto, const char *fmt)
 	return res;
 }
 
-int pcb_load_padstack(rnd_hidlib_t *hidlib, pcb_pstk_proto_t *proto, const char *fn, const char *fmt)
+int pcb_load_padstack(rnd_design_t *hidlib, pcb_pstk_proto_t *proto, const char *fn, const char *fmt)
 {
 	int res = -1, len, n;
 	pcb_find_io_t available[PCB_IO_MAX_FORMATS];
@@ -643,11 +643,11 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 		pcb_board_new_postproc(PCB, 0);
 		if (how == 0) {
 			/* update cursor location */
-			PCB->hidlib.ch_x = pcb_crosshair.X = PCB->hidlib.size_x/2;
-			PCB->hidlib.ch_y = pcb_crosshair.Y = PCB->hidlib.size_y/2;
+			PCB->hidlib.ch_x = pcb_crosshair.X = (PCB->hidlib.dwg.X1 + PCB->hidlib.dwg.X2) / 2;
+			PCB->hidlib.ch_y = pcb_crosshair.Y = (PCB->hidlib.dwg.Y1 + PCB->hidlib.dwg.Y2) / 2;
 
 			/* update cursor confinement and output area (scrollbars) */
-			pcb_board_resize(PCB->hidlib.size_x, PCB->hidlib.size_y, 0);
+			pcb_board_resize(PCB->hidlib.dwg.X1, PCB->hidlib.dwg.Y1, PCB->hidlib.dwg.X2, PCB->hidlib.dwg.Y2, 0);
 		}
 
 		/* have to be called after pcb_board_resize() so vis update is after a board changed update */
@@ -666,7 +666,7 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 
 		/* clear 'changed flag' */
 		pcb_board_set_changed_flag(PCB, rnd_false);
-		PCB->hidlib.filename = new_filename;
+		PCB->hidlib.loadname = new_filename;
 		/* just in case a bad file saved file is loaded */
 
 		/* geda/pcb compatibility: use attribute PCB::grid::unit as unit, if present */
@@ -692,7 +692,7 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 	}
 
 		if ((how == 0) || (revert))
-			pcb_board_changed(revert);
+			pcb_board_replaced();
 
 #ifdef DEBUG
 		end = clock();
@@ -718,7 +718,7 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 	}
 
 	if (!(how & PCB_INHIBIT_BOARD_CHANGED))
-		pcb_board_changed(0);
+		pcb_board_replaced();
 
 	/* release unused memory */
 	pcb_board_remove(newPCB);
@@ -834,7 +834,7 @@ int pcb_load_pcb(const char *file, const char *fmt, rnd_bool require_font, int h
 				res = -1;
 			}
 			else
-				pcb_board_resize(b.X2*1.5, b.Y2*1.5, 0);
+				pcb_board_resize(b.X1, b.Y1, b.X2*1.5, b.Y2*1.5, 0);
 		}
 	}
 	return res;
@@ -842,10 +842,10 @@ int pcb_load_pcb(const char *file, const char *fmt, rnd_bool require_font, int h
 
 int pcb_revert_pcb(void)
 {
-	return real_load_pcb(PCB->hidlib.filename, NULL, rnd_true, rnd_true, 0);
+	return real_load_pcb(PCB->hidlib.loadname, NULL, rnd_true, rnd_true, 0);
 }
 
-int pcb_load_buffer(rnd_hidlib_t *hidlib, pcb_buffer_t *buff, const char *fn, const char *fmt)
+int pcb_load_buffer(rnd_design_t *hidlib, pcb_buffer_t *buff, const char *fn, const char *fmt)
 {
 	int res = -1, len, n;
 	pcb_find_io_t available[PCB_IO_MAX_FORMATS];
@@ -1132,7 +1132,7 @@ rnd_cardinal_t pcb_io_incompat_save(pcb_data_t *data, pcb_any_obj_t *obj, const
 	return 0;
 }
 
-pcb_plug_fp_map_t *pcb_io_map_footprint_file(rnd_hidlib_t *hl, const char *fn, pcb_plug_fp_map_t *head, int need_tags, const char **fmt)
+pcb_plug_fp_map_t *pcb_io_map_footprint_file(rnd_design_t *hl, const char *fn, pcb_plug_fp_map_t *head, int need_tags, const char **fmt)
 {
 	FILE *f = rnd_fopen(hl, fn, "r");
 	pcb_plug_fp_map_t *res = NULL;
