@@ -39,9 +39,11 @@
 #include <librnd/core/compat_misc.h>
 #include "obj_subc.h"
 #include <librnd/core/rnd_printf.h>
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_dad_tree.h>
-#include <librnd/core/hid_menu.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_dad_tree.h>
+#include <librnd/hid/hid_menu.h>
+#include <librnd/core/hidlib.h>
+#include <librnd/core/conf_multi.h>
 #include "search.h"
 #include "draw.h"
 #include "select.h"
@@ -369,7 +371,7 @@ static void asm_greyout(int grey)
 			ly->meta.real.color = asm_ctx.layer_colors.array[n];
 		vtclr_uninit(&asm_ctx.layer_colors);
 	}
-	rnd_hid_redraw(PCB);
+	rnd_hid_redraw(&PCB->hidlib);
 }
 
 /*** UI callbacks ***/
@@ -448,7 +450,7 @@ static void asm_row_selected(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid
 	rnd_gui->attr_dlg_widget_state(hid_ctx, asm_ctx.wdoneg, isgrp | ispart);
 	rnd_gui->attr_dlg_widget_state(hid_ctx, asm_ctx.wskipp, ispart);
 	rnd_gui->attr_dlg_widget_state(hid_ctx, asm_ctx.wdonep, ispart);
-	rnd_hid_redraw(PCB); /* for displaying the new selection */
+	rnd_hid_redraw(&PCB->hidlib); /* for displaying the new selection */
 }
 
 static void skip(void *hid_ctx, int pick_grp, rnd_hid_row_t *row)
@@ -506,9 +508,9 @@ static void done(void *hid_ctx, part_t *part, int done)
 {
 	part->done = done;
 	if (done)
-		rnd_dad_tree_modify_cell(&asm_ctx.dlg[asm_ctx.wtbl], part->row, 5, "yes");
+		rnd_dad_tree_modify_cell(&asm_ctx.dlg[asm_ctx.wtbl], part->row, 5, rnd_strdup("yes"));
 	else
-		rnd_dad_tree_modify_cell(&asm_ctx.dlg[asm_ctx.wtbl], part->row, 5, "-");
+		rnd_dad_tree_modify_cell(&asm_ctx.dlg[asm_ctx.wtbl], part->row, 5, rnd_strdup("-"));
 	group_progress_update(hid_ctx, part->parent);
 }
 
@@ -580,7 +582,7 @@ static const char pcb_acth_asm[] = "Interactive assembly assistant";
 fgw_error_t pcb_act_asm(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	const char *hdr[] = { "name", "refdes", "footprint", "value", "comments", "done", NULL };
-	char *row[7];
+	char *cell[7];
 	group_t **g;
 	part_t **p;
 	long n, i;
@@ -604,14 +606,14 @@ fgw_error_t pcb_act_asm(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			RND_DAD_COMPFLAG(asm_ctx.dlg, RND_HATF_SCROLL);
 			for(g = (group_t **)asm_ctx.grps.array, n = 0; n < asm_ctx.grps.used; g++,n++) {
 				rnd_hid_row_t *parent, *child;
-				row[0] = (*g)->name;
-				row[1] = "";
-				row[2] = "";
-				row[3] = "";
-				row[4] = "";
-				row[5] = "";
-				row[6] = NULL;
-				parent = RND_DAD_TREE_APPEND(asm_ctx.dlg, NULL, row);
+				cell[0] = rnd_strdup((*g)->name);
+				cell[1] = rnd_strdup("");
+				cell[2] = rnd_strdup("");
+				cell[3] = rnd_strdup("");
+				cell[4] = rnd_strdup("");
+				cell[5] = rnd_strdup("");
+				cell[6] = NULL;
+				parent = RND_DAD_TREE_APPEND(asm_ctx.dlg, NULL, cell);
 				parent->user_data = *g;
 				(*g)->row = parent;
 				for(p = (part_t **)(*g)->parts.array, i = 0; i < (*g)->parts.used; p++,i++) {
@@ -622,27 +624,29 @@ fgw_error_t pcb_act_asm(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					type = pcb_search_obj_by_id_(PCB->Data, &r1, &r2, &r3, (*p)->id, PCB_OBJ_SUBC);
 					sc = r2;
 
-					row[0] = (*p)->name;
+					cell[0] = rnd_strdup((*p)->name);
 					if (type == PCB_OBJ_SUBC) {
 						int m;
-						row[1] = (char *)sc->refdes;
-						row[2] = pcb_attribute_get(&sc->Attributes, "footprint");
-						row[3] = pcb_attribute_get(&sc->Attributes, "value");
-						row[4] = pcb_attribute_get(&sc->Attributes, "asm::comment");
-						row[5] = "";
-						for(m = 1; m < 6; m++)
-							if (row[m] == NULL)
-								row[m] = "";
+						cell[1] = (char *)sc->refdes;
+						cell[2] = pcb_attribute_get(&sc->Attributes, "footprint");
+						cell[3] = pcb_attribute_get(&sc->Attributes, "value");
+						cell[4] = pcb_attribute_get(&sc->Attributes, "asm::comment");
+						cell[5] = "";
+						for(m = 1; m < 6; m++) {
+							if (cell[m] == NULL)
+								cell[m] = "";
+							cell[m] = rnd_strdup(cell[m]);
+						}
 					}
 					else {
-						row[1] = "";
-						row[2] = "";
-						row[3] = "";
-						row[4] = "";
-						row[5] = "";
+						cell[1] = rnd_strdup("");
+						cell[2] = rnd_strdup("");
+						cell[3] = rnd_strdup("");
+						cell[4] = rnd_strdup("");
+						cell[5] = rnd_strdup("");
 					}
-					row[6] = NULL;
-					child = RND_DAD_TREE_APPEND_UNDER(asm_ctx.dlg, parent, row);
+					cell[6] = NULL;
+					child = RND_DAD_TREE_APPEND_UNDER(asm_ctx.dlg, parent, cell);
 					child->user_data = *p;
 					(*p)->row = child;
 				}
@@ -698,14 +702,14 @@ void pplg_uninit_asm(void)
 {
 	rnd_hid_menu_unload(rnd_gui, asm_cookie);
 	rnd_remove_actions_by_cookie(asm_cookie);
-	rnd_conf_unreg_intern(asm_conf_internal);
-	rnd_conf_unreg_fields("plugins/asm1/");
+	rnd_conf_plug_unreg("plugins/asm1/", asm_conf_internal, asm_cookie);
 }
 
 int pplg_init_asm(void)
 {
 	RND_API_CHK_VER;
-	rnd_conf_reg_intern(asm_conf_internal);
+
+	rnd_conf_plug_reg(conf_asm, asm_conf_internal, asm_cookie);
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
 	rnd_conf_reg_field(conf_asm, field,isarray,type_name,cpath,cname,desc,flags);
 #include "asm_conf_fields.h"
