@@ -41,13 +41,13 @@
 #include "event.h"
 #include "obj_subc.h"
 #include "plug_footprint.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include "undo.h"
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_dad_tree.h>
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_dad_tree.h>
+#include <librnd/hid/hid_init.h>
 
 #include "dlg_library.h"
 
@@ -363,7 +363,7 @@ static void library_select(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_r
 
 }
 
-static void library_expose(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void library_expose(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 	library_ctx_t *ctx = prv->user_ctx;
 	int orig_po = pcb_draw_force_termlab;
@@ -730,8 +730,7 @@ static void pcb_dlg_library(void)
 
 	RND_DAD_BEGIN_VBOX(library_ctx.dlg);
 		RND_DAD_COMPFLAG(library_ctx.dlg, RND_HATF_EXPFILL);
-		RND_DAD_BEGIN_HPANE(library_ctx.dlg);
-			RND_DAD_SET_PANE_NAME(library_ctx.dlg, "left-right");
+		RND_DAD_BEGIN_HPANE(library_ctx.dlg, "left-right");
 
 			/* left */
 			RND_DAD_BEGIN_VBOX(library_ctx.dlg);
@@ -758,8 +757,7 @@ static void pcb_dlg_library(void)
 			RND_DAD_END(library_ctx.dlg);
 
 			/* right */
-			RND_DAD_BEGIN_VPANE(library_ctx.dlg);
-				RND_DAD_SET_PANE_NAME(library_ctx.dlg, "top-bottom");
+			RND_DAD_BEGIN_VPANE(library_ctx.dlg, "top-bottom");
 				RND_DAD_COMPFLAG(library_ctx.dlg, RND_HATF_EXPFILL | RND_HATF_FRAME);
 				RND_DAD_BEGIN_VBOX(library_ctx.dlg);
 					/* right top: preview */
@@ -842,7 +840,7 @@ fgw_error_t pcb_act_LibraryDialog(fgw_arg_t *ores, int oargc, fgw_arg_t *oargv)
 	return 0;
 }
 
-static void library_changed_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void library_changed_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if (library_ctx.active)
 		library_lib2dlg(&library_ctx);
