@@ -31,10 +31,10 @@
 #include "board.h"
 #include "data.h"
 #include <librnd/core/event.h>
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 #include <librnd/core/compat_fs.h>
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include "plug_io.h"
 #include <librnd/plugins/lib_hid_common/dialogs_conf.h>
 
@@ -66,7 +66,7 @@ fgw_error_t pcb_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* Called with both function and file name -> no gui */
 	if (argc > 2)
-		return RND_ACT_CALL_C(RND_ACT_HIDLIB, pcb_act_LoadFrom, res, argc, argv);
+		return RND_ACT_CALL_C(RND_ACT_DESIGN, pcb_act_LoadFrom, res, argc, argv);
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, Load, function = argv[1].val.str);
 
@@ -87,7 +87,7 @@ fgw_error_t pcb_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (name != NULL) {
 		if (rnd_conf.rc.verbose)
 			fprintf(stderr, "Load:  Calling LoadFrom(%s, %s)\n", function, name);
-		rnd_actionva(RND_ACT_HIDLIB, "LoadFrom", function, name, NULL);
+		rnd_actionva(RND_ACT_DESIGN, "LoadFrom", function, name, NULL);
 		free(name);
 	}
 
@@ -404,7 +404,7 @@ fgw_error_t pcb_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	save_t save;
 	rnd_hidval_t timer_ctx;
 	const char *default_pattern = NULL;
-	pcb_plug_iot_t list_iot;
+	pcb_plug_iot_t list_iot = 0;
 	pcb_io_list_ext_t list_ext;
 	int dialog_by_pattern = 0, is_dialog, init_fmt_known = 0;
 
@@ -416,13 +416,16 @@ fgw_error_t pcb_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	is_dialog = (function != NULL) && (rnd_strncasecmp(function, "Dialog", 6) == 0);
 
 	if ((!is_dialog) && (argc > 2))
-		return RND_ACT_CALL_C(RND_ACT_HIDLIB, pcb_act_SaveTo, res, argc, argv);
+		return RND_ACT_CALL_C(RND_ACT_DESIGN, pcb_act_SaveTo, res, argc, argv);
 
 	memset(&save, 0, sizeof(save));
 
 	if (rnd_strcasecmp(function, "Layout") == 0)
-		if (PCB->hidlib.filename != NULL)
-			return rnd_actionva(RND_ACT_HIDLIB, "SaveTo", "Layout", NULL);
+		if (PCB->hidlib.loadname != NULL)
+			return rnd_actionva(RND_ACT_DESIGN, "SaveTo", "Layout", NULL);
+
+	if (rnd_strcasecmp(function, "LayoutAs") == 0)
+		list_iot = PCB_IOT_PCB;
 
 	if (is_dialog) {
 		const char *siot, *sext;
@@ -548,10 +551,10 @@ fgw_error_t pcb_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* construct the input file name and run a file selection dialog to get the final file name */
 	if (name_in == NULL) {
-		if (PCB->hidlib.filename == NULL)
+		if (PCB->hidlib.loadname == NULL)
 			name_in = rnd_concat("unnamed", extensions_param[fmt], NULL);
 		else
-			name_in = rnd_strdup(PCB->hidlib.filename);
+			name_in = rnd_strdup(PCB->hidlib.loadname);
 	}
 
 
@@ -569,7 +572,7 @@ fgw_error_t pcb_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	timer_ctx.ptr = &save;
 	save.timer_active = 1;
 	save.timer = rnd_gui->add_timer(rnd_gui, save_timer, 300, timer_ctx); /* the timer needs to run at least once, to get some initialization done that can be done only after fmtsub got created */
-	final_name = rnd_hid_fileselect(rnd_gui, prompt, NULL, name_in, NULL, NULL, "board", RND_HID_FSD_MAY_NOT_EXIST, fmtsub);
+	final_name = rnd_hid_fileselect(rnd_gui, prompt, NULL, name_in, NULL, NULL, "board", 0, fmtsub);
 	if (save.timer_active)
 		rnd_gui->stop_timer(rnd_gui, save.timer);
 	free(name_in);
@@ -605,7 +608,7 @@ fgw_error_t pcb_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		const char *sfmt = avail.plug[fmt]->description;
 		if (fmt_param != NULL)
 			sfmt = avail.plug[save.pick]->description;
-		rnd_actionva(RND_ACT_HIDLIB, "PasteBuffer", "Save", final_name, sfmt, NULL);
+		rnd_actionva(RND_ACT_DESIGN, "PasteBuffer", "Save", final_name, sfmt, NULL);
 	}
 	else {
 		const char *sfmt = NULL;
@@ -618,9 +621,9 @@ fgw_error_t pcb_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		 * just obtained.
 		 */
 		if (rnd_strcasecmp(function, "Layout") == 0)
-			rnd_actionva(RND_ACT_HIDLIB, "SaveTo", "LayoutAs", final_name, sfmt, NULL);
+			rnd_actionva(RND_ACT_DESIGN, "SaveTo", "LayoutAs", final_name, sfmt, NULL);
 		else
-			rnd_actionva(RND_ACT_HIDLIB, "SaveTo", function, final_name, sfmt, NULL);
+			rnd_actionva(RND_ACT_DESIGN, "SaveTo", function, final_name, sfmt, NULL);
 	}
 
 	free(final_name);
