@@ -52,11 +52,11 @@
 #include "plug_io.h"
 #include <librnd/core/safe_fs.h>
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
 
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
 #include "hid_cam.h"
 
 #include "../src_plugins/lib_compat_help/pstk_compat.h"
@@ -81,12 +81,12 @@ static const rnd_export_opt_t fidocadj_attribute_list[] = {
 
 static rnd_hid_attr_val_t fidocadj_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *fidocadj_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *fidocadj_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *suffix = ".fcd";
 	const char *val = fidocadj_values[HA_fidocadjfile].str;
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &fidocadj_values[HA_fidocadjfile], suffix);
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &fidocadj_values[HA_fidocadjfile], suffix);
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -160,7 +160,7 @@ static void write_custom_subc(FILE *f, pcb_subc_t *sc)
 	free(msg);
 }
 
-static void fidocadj_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void fidocadj_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	FILE *f;
 	const char *filename, *libfile;
@@ -169,7 +169,7 @@ static void fidocadj_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	htsi_t lib_names; /* hash of names found in the library, if have_lib is 1 */
 
 	if (!options) {
-		fidocadj_get_export_options(hid, 0);
+		fidocadj_get_export_options(hid, 0, design, appspec);
 		options = fidocadj_values;
 	}
 
