@@ -27,14 +27,14 @@
 #include "gerber_conf.h"
 #include <librnd/core/event.h>
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
-#include <librnd/core/hid_inlines.h>
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
+#include <librnd/hid/hid_inlines.h>
+#include <librnd/hid/hid_dad.h>
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include <librnd/core/actions.h>
 
 #include "../src_plugins/export_excellon/aperture.h"
@@ -56,7 +56,7 @@ static pcb_cam_t gerber_cam;
 
 /* These are for films */
 #define gerberX(pcb, x) ((rnd_coord_t) (x))
-#define gerberY(pcb, y) ((rnd_coord_t) ((pcb)->hidlib.size_y - (y)))
+#define gerberY(pcb, y) ((rnd_coord_t) ((pcb)->hidlib.dwg.Y2 - (y)))
 #define gerberXOffset(pcb, x) ((rnd_coord_t) (x))
 #define gerberYOffset(pcb, y) ((rnd_coord_t) (-(y)))
 
@@ -256,11 +256,11 @@ Print file names and aperture counts on stdout.
 
 static rnd_hid_attr_val_t gerber_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *gerber_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *gerber_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *val = gerber_values[HA_gerberfile].str;
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &gerber_values[HA_gerberfile], "");
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &gerber_values[HA_gerberfile], "");
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -309,7 +309,7 @@ static void append_file_suffix(gds_t *dst, rnd_layergrp_id_t gid, rnd_layer_id_t
 	filesuff = fn_gds.array + fn_baselen;
 }
 
-static void gerber_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void gerber_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	const char *fnbase;
 	int i;
@@ -323,7 +323,7 @@ static void gerber_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	drawing_mode_issued = RND_HID_COMP_POSITIVE;
 
 	if (!options) {
-		gerber_get_export_options(hid, NULL);
+		gerber_get_export_options(hid, NULL, design, appspec);
 		options = gerber_values;
 	}
 
@@ -371,10 +371,11 @@ static void gerber_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	lastgroup = -1;
 	lastcolor = -1;
 
-	ctx.view.X1 = 0;
-	ctx.view.Y1 = 0;
-	ctx.view.X2 = PCB->hidlib.size_x;
-	ctx.view.Y2 = PCB->hidlib.size_y;
+	ctx.design = design;
+	ctx.view.X1 = design->dwg.X1;
+	ctx.view.Y1 = design->dwg.Y1;
+	ctx.view.X2 = design->dwg.X2;
+	ctx.view.Y2 = design->dwg.Y2;
 
 	pagecount = 1;
 	reset_apertures();
@@ -424,7 +425,7 @@ static int gerber_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 
 
 
-static int gerber_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int gerber_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	int want_outline;
 	char *cp;
@@ -550,7 +551,7 @@ static int gerber_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const
 		fprintf(f, "G04 For: %s *\r\n", pcb_author());
 
 		fprintf(f, "G04 Format: Gerber/RS-274X *\r\n");
-		rnd_fprintf(f, "G04 PCB-Dimensions: %[4] %[4] *\r\n", PCB->hidlib.size_x, PCB->hidlib.size_y);
+		rnd_fprintf(f, "G04 PCB-Dimensions: %[4] %[4] *\r\n", rnd_dwg_get_size_x(&PCB->hidlib), rnd_dwg_get_size_y(&PCB->hidlib));
 		fprintf(f, "G04 PCB-Coordinate-Origin: lower left *\r\n");
 
 		/* Unit and coord format */
@@ -611,10 +612,10 @@ emit_outline:
 				rnd_hid_set_line_width(gc, conf_core.design.min_wid);
 			else
 				rnd_hid_set_line_width(gc, AUTO_OUTLINE_WIDTH);
-			rnd_render->draw_line(gc, 0, 0, PCB->hidlib.size_x, 0);
-			rnd_render->draw_line(gc, 0, 0, 0, PCB->hidlib.size_y);
-			rnd_render->draw_line(gc, PCB->hidlib.size_x, 0, PCB->hidlib.size_x, PCB->hidlib.size_y);
-			rnd_render->draw_line(gc, 0, PCB->hidlib.size_y, PCB->hidlib.size_x, PCB->hidlib.size_y);
+			rnd_render->draw_line(gc, PCB->hidlib.dwg.X1, PCB->hidlib.dwg.Y1, PCB->hidlib.dwg.X2, PCB->hidlib.dwg.Y1);
+			rnd_render->draw_line(gc, PCB->hidlib.dwg.X1, PCB->hidlib.dwg.Y1, PCB->hidlib.dwg.X1, PCB->hidlib.dwg.Y2);
+			rnd_render->draw_line(gc, PCB->hidlib.dwg.X2, PCB->hidlib.dwg.Y1, PCB->hidlib.dwg.X2, PCB->hidlib.dwg.Y2);
+			rnd_render->draw_line(gc, PCB->hidlib.dwg.X1, PCB->hidlib.dwg.Y2, PCB->hidlib.dwg.X2, PCB->hidlib.dwg.Y2);
 			rnd_hid_destroy_gc(gc);
 		}
 	}
@@ -1059,12 +1060,7 @@ static void gerber_warning(rnd_hid_export_opt_func_action_t act, void *call_ctx,
 	}
 }
 
-
-static void gerber_set_crosshair(rnd_hid_t *hid, rnd_coord_t x, rnd_coord_t y, int action)
-{
-}
-
-static void gerber_session_begin(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void gerber_session_begin(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	gerber_global_aperture_cnt = 0;
 }
@@ -1116,7 +1112,6 @@ int pplg_init_export_gerber(void)
 	gerber_hid.fill_polygon = gerber_fill_polygon;
 	gerber_hid.fill_polygon_offs = gerber_fill_polygon_offs;
 	gerber_hid.fill_rect = gerber_fill_rect;
-	gerber_hid.set_crosshair = gerber_set_crosshair;
 	gerber_hid.usage = gerber_usage;
 	gerber_hid.argument_array = gerber_values;
 
