@@ -45,8 +45,8 @@
 #include "funchash_core.h"
 #include "search.h"
 
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
 
 const char *oldconn_cookie = "export_oldconn HID";
 
@@ -202,9 +202,6 @@ static void pcb_lookup_unused_pins(FILE *f, int do_select)
 	}
 	PCB_END_LOOP;
 
-	if (conf_core.editor.beep_when_finished)
-		rnd_gui->beep(rnd_gui);
-
 	if (do_select) {
 		pcb_undo_inc_serial();
 		pcb_draw();
@@ -215,8 +212,6 @@ static void pcb_lookup_unused_pins(FILE *f, int do_select)
 static void pcb_lookup_subc_conns(FILE *f, pcb_subc_t *subc)
 {
 	pcb_print_subc_conns(f, subc);
-	if (conf_core.editor.beep_when_finished)
-		rnd_gui->beep(rnd_gui);
 }
 
 /* Find all connections from all terminals of all subcircuits and print in f. */
@@ -229,9 +224,7 @@ static void pcb_lookup_conns_to_all_subcs(FILE *f)
 	}
 	PCB_END_LOOP;
 
-	if (conf_core.editor.beep_when_finished)
-		rnd_gui->beep(rnd_gui);
-	rnd_hid_redraw(PCB);
+	rnd_hid_redraw(&PCB->hidlib);
 }
 
 static FILE *pcb_check_and_open_file(const char *Filename)
