@@ -51,12 +51,12 @@
 #include "obj_pstk_inlines.h"
 #include "funchash_core.h"
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
 
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid_init.h>
 #include <librnd/core/actions.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid_attrib.h>
 #include "hid_cam.h"
 
 
@@ -131,28 +131,29 @@ Name of the file to be exported to. Can contain a path.
 
 static rnd_hid_attr_val_t openscad_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *openscad_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *openscad_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *suffix = ".scad";
 	const char *val = openscad_values[HA_openscadfile].str;
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &openscad_values[HA_openscadfile], suffix);
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &openscad_values[HA_openscadfile], suffix);
 
 	if (n)
 		*n = NUM_OPTIONS;
 	return openscad_attribute_list;
 }
 
-void openscad_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options)
+void openscad_hid_export_to_file(rnd_design_t *dsg, FILE * the_file, rnd_hid_attr_val_t * options)
 {
 	static int saved_layer_stack[PCB_MAX_LAYER];
 	rnd_hid_expose_ctx_t ctx;
 
-	ctx.view.X1 = 0;
-	ctx.view.Y1 = 0;
-	ctx.view.X2 = PCB->hidlib.size_x;
-	ctx.view.Y2 = PCB->hidlib.size_y;
+	ctx.design = dsg;
+	ctx.view.X1 = dsg->dwg.X1;
+	ctx.view.Y1 = dsg->dwg.Y1;
+	ctx.view.X2 = dsg->dwg.X2;
+	ctx.view.Y2 = dsg->dwg.Y2;
 
 	f = the_file;
 
@@ -296,14 +297,14 @@ static void scad_new_layer_group(const char *group_name, int level, const char *
 }
 
 
-static void openscad_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void openscad_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	const char *filename;
 	int save_ons[PCB_MAX_LAYER];
 	pcb_cam_t cam;
 
 	if (!options) {
-		openscad_get_export_options(hid, 0);
+		openscad_get_export_options(hid, 0, design, appspec);
 		options = openscad_values;
 	}
 
@@ -334,7 +335,7 @@ static void openscad_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	if (options[HA_models].lng)
 		scad_insert_models();
 
-	openscad_hid_export_to_file(f, options);
+	openscad_hid_export_to_file(design, f, options);
 	scad_close_layer_group();
 
 	if (options[HA_drill].lng)
@@ -361,7 +362,7 @@ static int openscad_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 
 
 
-static int openscad_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int openscad_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	if (flags & PCB_LYT_UI)
 		return 0;
@@ -583,10 +584,6 @@ static void openscad_fill_polygon(rnd_hid_gc_t gc, int n_coords, rnd_coord_t *x,
 	openscad_fill_polygon_offs(gc, n_coords, x, y, 0, 0);
 }
 
-static void openscad_set_crosshair(rnd_hid_t *hid, rnd_coord_t x, rnd_coord_t y, int a)
-{
-}
-
 static int openscad_usage(rnd_hid_t *hid, const char *topic)
 {
 	fprintf(stderr, "\nopenscad exporter command line arguments:\n\n");
@@ -691,7 +688,6 @@ int pplg_init_export_openscad(void)
 	openscad_hid.fill_polygon = openscad_fill_polygon;
 	openscad_hid.fill_polygon_offs = openscad_fill_polygon_offs;
 	openscad_hid.fill_rect = openscad_fill_rect;
-	openscad_hid.set_crosshair = openscad_set_crosshair;
 	openscad_hid.argument_array = openscad_values;
 
 	openscad_hid.usage = openscad_usage;
