@@ -53,10 +53,10 @@
 #include "funchash_core.h"
 #include "hid_cam.h"
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
 #include <librnd/core/compat_misc.h>
 
 /* we depend on <gd.h> for photo mode */
@@ -296,13 +296,13 @@ In photo-realistic mode, export the silk screen as this colour. Parameter
 
 static rnd_hid_attr_val_t png_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *png_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *png_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *suffix = rnd_drwpx_get_file_suffix(png_values[HA_filetype].lng);
 	const char *val = png_values[HA_pngfile].str;
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &png_values[HA_pngfile], suffix);
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &png_values[HA_pngfile], suffix);
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -365,7 +365,7 @@ static void png_finish(FILE *f)
 }
 
 
-void png_hid_export_to_file(FILE *the_file, rnd_hid_attr_val_t *options, rnd_xform_t *xform)
+void png_hid_export_to_file(rnd_design_t *dsg, FILE *the_file, rnd_hid_attr_val_t *options, rnd_xform_t *xform)
 {
 	static int saved_layer_stack[PCB_MAX_LAYER];
 	rnd_box_t tmp, region;
@@ -373,10 +373,10 @@ void png_hid_export_to_file(FILE *the_file, rnd_hid_attr_val_t *options, rnd_xfo
 
 	png_f = the_file;
 
-	region.X1 = 0;
-	region.Y1 = 0;
-	region.X2 = PCB->hidlib.size_x;
-	region.Y2 = PCB->hidlib.size_y;
+	region.X1 = dsg->dwg.X1;
+	region.Y1 = dsg->dwg.Y1;
+	region.X2 = dsg->dwg.X2;
+	region.Y2 = dsg->dwg.Y2;
 
 	png_options = options;
 	if (options[HA_only_visible].lng)
@@ -419,6 +419,7 @@ void png_hid_export_to_file(FILE *the_file, rnd_hid_attr_val_t *options, rnd_xfo
 		xform->add_gui_xform = 1;
 	}
 
+	ctx.design = dsg;
 	ctx.view = *bounds;
 	rnd_app.expose_main(&png_hid, &ctx, xform);
 
@@ -426,7 +427,7 @@ void png_hid_export_to_file(FILE *the_file, rnd_hid_attr_val_t *options, rnd_xfo
 	rnd_conf_update(NULL, -1); /* restore forced sets */
 }
 
-static void png_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void png_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	int save_ons[PCB_MAX_LAYER];
 	rnd_box_t tmp, *bbox;
@@ -435,7 +436,7 @@ static void png_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	rnd_drwpx_init(pctx, &PCB->hidlib);
 
 	if (!options) {
-		png_get_export_options(hid, 0);
+		png_get_export_options(hid, 0, design, appspec);
 		options = png_values;
 	}
 
@@ -487,7 +488,7 @@ static void png_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	if ((!png_cam.active) && (!options[HA_as_shown].lng))
 		pcb_hid_save_and_show_layer_ons(save_ons);
 
-	png_hid_export_to_file(png_f, options, &xform);
+	png_hid_export_to_file(design, png_f, options, &xform);
 
 	if ((!png_cam.active) && (!options[HA_as_shown].lng))
 		pcb_hid_restore_layer_ons(save_ons);
@@ -521,7 +522,7 @@ static int png_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 
 static int is_mask;
 
-static int png_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int png_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	if (flags & PCB_LYT_UI)
 		return 0;
@@ -553,7 +554,7 @@ static int png_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const ch
 	is_mask = (flags & PCB_LYT_MASK);
 
 	if (pctx->photo_mode)
-		return png_set_layer_group_photo(group, purpose, purpi, layer, flags, is_empty, xform);
+		return png_set_layer_group_photo(group, design, purpose, purpi, layer, flags, is_empty, xform);
 
 	if (png_cam.active) /* CAM decided already */
 		return 1;
@@ -628,10 +629,6 @@ static void png_fill_polygon(rnd_hid_gc_t gc, int n_coords, rnd_coord_t *x, rnd_
 	png_fill_polygon_offs(gc, n_coords, x, y, 0, 0);
 }
 
-static void png_set_crosshair(rnd_hid_t *hid, rnd_coord_t x, rnd_coord_t y, int a)
-{
-}
-
 static int png_usage(rnd_hid_t *hid, const char *topic)
 {
 	fprintf(stderr, "\npng exporter command line arguments:\n\n");
@@ -681,7 +678,6 @@ int pplg_init_export_png(void)
 	png_hid.fill_polygon = png_fill_polygon;
 	png_hid.fill_polygon_offs = png_fill_polygon_offs;
 	png_hid.fill_rect = png_fill_rect;
-	png_hid.set_crosshair = png_set_crosshair;
 	png_hid.argument_array = png_values;
 
 	png_hid.usage = png_usage;
