@@ -23,11 +23,11 @@
 #include <librnd/core/safe_fs.h>
 #include <librnd/plugins/lib_exp_text/draw_eps.h>
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
 #include "ps.h"
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
 #include "hid_cam.h"
 #include "funchash_core.h"
 
@@ -112,12 +112,12 @@ Limit the bounds of the EPS file to the visible items.
 
 static rnd_hid_attr_val_t eps_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *eps_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *eps_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *val = eps_values[HA_psfile].str;
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &eps_values[HA_psfile], ".eps");
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &eps_values[HA_psfile], ".eps");
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -158,7 +158,7 @@ static const char *filename;
 
 static rnd_hid_attr_val_t *options_;
 
-void eps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t *options, rnd_xform_t *xform)
+void eps_hid_export_to_file(rnd_design_t *dsg, FILE * the_file, rnd_hid_attr_val_t *options, rnd_xform_t *xform)
 {
 	int i;
 	static int saved_layer_stack[PCB_MAX_LAYER];
@@ -167,10 +167,10 @@ void eps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t *options, rnd_xf
 
 	options_ = options;
 
-	region.X1 = 0;
-	region.Y1 = 0;
-	region.X2 = PCB->hidlib.size_x;
-	region.Y2 = PCB->hidlib.size_y;
+	region.X1 = dsg->dwg.X1;
+	region.Y1 = dsg->dwg.Y1;
+	region.X2 = dsg->dwg.X2;
+	region.Y2 = dsg->dwg.Y2;
 
 	if (options[HA_only_visible].lng)
 		bnds = pcb_data_bbox(&tmp, PCB->Data, rnd_false);
@@ -239,6 +239,7 @@ void eps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t *options, rnd_xf
 		xform->enable_silk_invis_clr = 1;
 	}
 
+	ctx.design = dsg;
 	ctx.view = *bnds;
 	rnd_app.expose_main(&eps_hid, &ctx, xform);
 
@@ -248,13 +249,13 @@ void eps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t *options, rnd_xf
 	options_ = NULL;
 }
 
-static void eps_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void eps_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	int save_ons[PCB_MAX_LAYER];
 	rnd_xform_t xform;
 
 	if (!options) {
-		eps_get_export_options(hid, 0);
+		eps_get_export_options(hid, 0, design, appspec);
 		options = eps_values;
 	}
 
@@ -277,7 +278,7 @@ static void eps_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	if ((!eps_cam.active) && (!options[HA_as_shown].lng))
 		pcb_hid_save_and_show_layer_ons(save_ons);
-	eps_hid_export_to_file(pctx->outf, options, &xform);
+	eps_hid_export_to_file(design, pctx->outf, options, &xform);
 	if ((!eps_cam.active) && (!options[HA_as_shown].lng))
 		pcb_hid_restore_layer_ons(save_ons);
 
@@ -305,7 +306,7 @@ static int is_mask;
 static int is_paste;
 static int is_drill;
 
-static int eps_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int eps_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	gds_t tmp_ln;
 	const char *name;
