@@ -21,13 +21,13 @@
 #include "funchash_core.h"
 #include "layer_vis.h"
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
 #include <librnd/plugins/lib_exp_text/draw_ps.h>
 
 #include "ps.h"
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
 #include <librnd/core/actions.h>
 #include "conf_core.h"
 #include <librnd/core/compat_misc.h>
@@ -37,7 +37,7 @@
 
 const char *ps_cookie = "ps HID";
 
-static int ps_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform);
+static int ps_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform);
 
 static pcb_cam_t ps_cam;
 
@@ -315,12 +315,12 @@ static struct {
 	int had_page; /* 1 if we ever wrote a page */
 } global;
 
-static const rnd_export_opt_t *ps_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *ps_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *val = global.ps_values[HA_psfile].str;
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &global.ps_values[HA_psfile], ".ps");
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &global.ps_values[HA_psfile], ".ps");
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -374,7 +374,7 @@ static FILE *psopen(const char *base, const char *which)
 
 
 /* This is used by other HIDs that use a postscript format, like lpr or eps.  */
-void ps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_xform_t *xform)
+void ps_hid_export_to_file(rnd_design_t *dsg, FILE * the_file, rnd_hid_attr_val_t * options, rnd_xform_t *xform, void *appspec_)
 {
 	static int saved_layer_stack[PCB_MAX_LAYER];
 
@@ -409,10 +409,11 @@ void ps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_xf
 	/* reset static vars */
 	rnd_ps_use_gc(&global.ps, NULL);
 
-	global.exps.view.X1 = 0;
-	global.exps.view.Y1 = 0;
-	global.exps.view.X2 = PCB->hidlib.size_x;
-	global.exps.view.Y2 = PCB->hidlib.size_y;
+	global.exps.design = dsg;
+	global.exps.view.X1 = dsg->dwg.X1;
+	global.exps.view.Y1 = dsg->dwg.Y1;
+	global.exps.view.X2 = dsg->dwg.X2;
+	global.exps.view.Y2 = dsg->dwg.Y2;
 
 	global.had_page = 0;
 
@@ -432,7 +433,7 @@ void ps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_xf
 	memcpy(pcb_layer_stack, saved_layer_stack, sizeof(pcb_layer_stack));
 }
 
-static void ps_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void ps_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	FILE *fh;
 	int save_ons[PCB_MAX_LAYER];
@@ -441,7 +442,7 @@ static void ps_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	global.ovr_all = 0;
 
 	if (!options) {
-		ps_get_export_options(hid, 0);
+		ps_get_export_options(hid, 0, design, appspec);
 		options = global.ps_values;
 	}
 
@@ -475,7 +476,7 @@ static void ps_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	if (!ps_cam.active)
 		pcb_hid_save_and_show_layer_ons(save_ons);
-	ps_hid_export_to_file(fh, options, &xform);
+	ps_hid_export_to_file(design, fh, options, &xform, appspec);
 	if (!ps_cam.active)
 		pcb_hid_restore_layer_ons(save_ons);
 
@@ -504,7 +505,7 @@ static int ps_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
-static int ps_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int ps_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	gds_t tmp_ln;
 	const char *name;
@@ -600,7 +601,7 @@ static int ps_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const cha
 		   If users don't want to make smaller boards, or use fewer drill
 		   sizes, they can always ignore this sheet. */
 		if (PCB_LAYER_IS_FAB(flags, purpi)) {
-			rnd_coord_t natural = boffset - RND_MIL_TO_COORD(500) - PCB->hidlib.size_y / 2;
+			rnd_coord_t natural = boffset - RND_MIL_TO_COORD(500) - (PCB->hidlib.dwg.Y1 + PCB->hidlib.dwg.Y2) / 2;
 			rnd_coord_t needed = pcb_stub_draw_fab_overhang();
 			rnd_fprintf(global.ps.outf, "%% PrintFab overhang natural %mi, needed %mi\n", natural, needed);
 			if (needed > natural)
@@ -715,7 +716,6 @@ void ps_ps_init(rnd_hid_t * hid)
 	hid->set_line_cap = rnd_ps_set_line_cap;
 	hid->set_line_width = rnd_ps_set_line_width;
 	hid->set_draw_xor = rnd_ps_set_draw_xor;
-	hid->set_draw_faded = rnd_ps_set_draw_faded;
 	hid->draw_line = ps_draw_line;
 	hid->draw_arc = ps_draw_arc;
 	hid->draw_rect = ps_draw_rect;
