@@ -1,6 +1,6 @@
 #include "config.h"
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -27,11 +27,11 @@
 #include "operation.h"
 #include "xy_conf.h"
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
+#include <librnd/hid/hid_attrib.h>
 #include "hid_cam.h"
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid_init.h>
 
 #include "../src_plugins/lib_compat_help/elem_rot.h"
 #include "../src_plugins/export_xy/conf_internal.c"
@@ -102,7 +102,7 @@ static void free_fmts(void)
 	}
 }
 
-static const rnd_export_opt_t *xy_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *xy_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	static int last_unit_value = -1;
 	rnd_conf_listitem_t *li;
@@ -152,8 +152,8 @@ static const rnd_export_opt_t *xy_get_export_options(rnd_hid_t *hid, int *n)
 		last_unit_value = xy_values[HA_unit].lng;
 	}
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &xy_values[HA_xyfile], ".xy");
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &xy_values[HA_xyfile], ".xy");
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -219,9 +219,9 @@ static void find_origin(subst_ctx_t *ctx, const char *format_name)
 {
 	/* default: bottom left of the drawing area */
 	ctx->ox = 0;
-	ctx->oy = PCB->hidlib.size_y;
-	ctx->bottom_ox = PCB->hidlib.size_x;
-	ctx->bottom_oy = PCB->hidlib.size_y;
+	ctx->oy = PCB->hidlib.dwg.Y2;
+	ctx->bottom_ox = PCB->hidlib.dwg.X2;
+	ctx->bottom_oy = PCB->hidlib.dwg.Y2;
 
 	find_origin_(format_name, "", &ctx->ox, &ctx->oy);
 	find_origin_(format_name, "bottom-", &ctx->bottom_ox, &ctx->bottom_oy);
@@ -388,12 +388,12 @@ static int subst_cb(void *ctx_, gds_t *s, const char **input)
 	}
 	if (strncmp(*input, "boardw%", 7) == 0) {
 		*input += 7;
-		rnd_append_printf(s, "%m+%mN", xy_unit->allow, PCB->hidlib.size_x);
+		rnd_append_printf(s, "%m+%mN", xy_unit->allow, PCB->hidlib.dwg.X2);
 		return 0;
 	}
 	if (strncmp(*input, "boardh%", 7) == 0) {
 		*input += 7;
-		rnd_append_printf(s, "%m+%mN", xy_unit->allow, PCB->hidlib.size_y);
+		rnd_append_printf(s, "%m+%mN", xy_unit->allow, PCB->hidlib.dwg.Y2);
 		return 0;
 	}
 	if (strncmp(*input, "subc.", 5) == 0) {
@@ -933,7 +933,7 @@ static const char *get_templ(const char *tid, const char *type)
 	return NULL;
 }
 
-static void xy_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void xy_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	template_t templ;
 	char **tid;
@@ -945,7 +945,7 @@ static void xy_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	gather_templates();
 
 	if (!options) {
-		xy_get_export_options(hid, 0);
+		xy_get_export_options(hid, 0, design, appspec);
 		options = xy_values;
 	}
 
@@ -955,10 +955,10 @@ static void xy_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	pcb_cam_begin_nolayer(PCB, &cam, NULL, options[HA_cam].str, &xy_filename);
 
-	if ((options[HA_unit].lng < 0) || (options[HA_unit].lng >= rnd_get_n_units(1)))
+	if ((options[HA_unit].lng < 0) || (options[HA_unit].lng >= rnd_get_n_units()))
 		xy_unit = rnd_get_unit_struct("mil");
 	else
-		xy_unit = &rnd_units[options[HA_unit].lng];
+		xy_unit = rnd_unit_get_idx(options[HA_unit].lng);
 
 	tid = vts0_get(&fmt_ids, options[HA_format].lng, 0);
 	if ((tid == NULL) || (*tid == NULL)) {
