@@ -302,7 +302,7 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (strcmp(opt, "inplace") == 0)
 		inplace = 1;
 
-	if (pcb->Changed && (rnd_hid_message_box(RND_ACT_HIDLIB, "warning", "Switching to fontedit", "OK to lose unsaved edits on this board?", "cancel", 0, "yes", 1, NULL) != 1)) {
+	if (pcb->Changed && (rnd_hid_message_box(RND_ACT_DESIGN, "warning", "Switching to fontedit", "OK to lose unsaved edits on this board?", "cancel", 0, "yes", 1, NULL) != 1)) {
 		RND_ACT_IRES(-1);
 		return 0;
 	}
@@ -317,7 +317,7 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		/* don't ask for losing changes twice */
 		pcb->Changed = 0;
 
-		if (rnd_actionva(RND_ACT_HIDLIB, "New", "Font", 0))
+		if (rnd_actionva(RND_ACT_DESIGN, "New", "Font", 0))
 			return 1;
 
 		pcb = PCB; /* our new board created above */
@@ -329,8 +329,8 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	rnd_conf_set_design("design/text_font_id", "%s", "0");
 
 
-	pcb->hidlib.size_x = CELL_SIZE * 18;
-	pcb->hidlib.size_y = CELL_SIZE * ((PCB_MAX_FONTPOSITION + 15) / 16 + 2);
+	pcb->hidlib.dwg.X2 = CELL_SIZE * 18;
+	pcb->hidlib.dwg.Y2 = CELL_SIZE * ((PCB_MAX_FONTPOSITION + 15) / 16 + 2);
 	pcb->hidlib.grid = RND_MIL_TO_COORD(5);
 
 	/* create the layer stack and logical layers */
@@ -353,18 +353,18 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pcb_layergrp_inhibit_dec();
 
 	/* Inform the rest about the board change (layer stack, size) */
-	rnd_event(&pcb->hidlib, RND_EVENT_BOARD_CHANGED, NULL);
+	rnd_event(&pcb->hidlib, RND_EVENT_DESIGN_SET_CURRENT, NULL);
 	rnd_event(&pcb->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
 
 	font2editor_new(pcb, font, lfont, lorig, lwidth, lsilk);
 
 	for (l = 0; l < 16; l++) {
 		int x = (l + 1) * CELL_SIZE;
-		pcb_line_new_merge(lgrid, x, 0, x, pcb->hidlib.size_y, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
+		pcb_line_new_merge(lgrid, x, 0, x, pcb->hidlib.dwg.Y2, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
 	}
 	for (l = 0; l <= PCB_MAX_FONTPOSITION / 16 + 1; l++) {
 		int y = (l + 1) * CELL_SIZE;
-		pcb_line_new_merge(lgrid, 0, y, pcb->hidlib.size_x, y, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
+		pcb_line_new_merge(lgrid, 0, y, pcb->hidlib.dwg.X2, y, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
 	}
 	RND_ACT_IRES(0);
 	return 0;
@@ -381,7 +381,7 @@ static fgw_error_t pcb_act_FontSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(1, FGW_STR, FontSave, fn = argv[1].val.str);
 
 	editor2font(pcb, font);
-	rnd_actionva(RND_ACT_HIDLIB, "SaveFontTo", fn, NULL);
+	rnd_actionva(RND_ACT_DESIGN, "SaveFontTo", fn, NULL);
 
 	RND_ACT_IRES(0);
 	return 0;
