@@ -121,15 +121,13 @@ static fgw_error_t pcb_act_DumpLibrary(fgw_arg_t *res, int argc, fgw_arg_t *argv
 
 /* ---------------------------------------------------------------------------
  * no operation, just for testing purposes
- * syntax: Bell(volume)
+ * syntax: Bell()
  */
 static const char pcb_acts_Bell[] = "Bell()";
-
 static const char pcb_acth_Bell[] = "Attempt to produce audible notification (e.g. beep the speaker).";
-
 static fgw_error_t pcb_act_Bell(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	rnd_gui->beep(rnd_gui);
+	rnd_message(RND_MSG_ERROR, "Bell(): beep not implemented any more. Please do not use the Bell() action.\n");
 	RND_ACT_IRES(0);
 	return 0;
 }
@@ -250,15 +248,12 @@ fgw_error_t pcb_act_ListRotations(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 static const char pcb_acts_PCBChanged[] = "PCBChanged([revert])";
 static const char pcb_acth_PCBChanged[] =
-	"Tells the GUI that the whole PCB has changed. The optional \"revert\""
-	"parameter can be used as a hint to the GUI that the same design is being"
-	"reloaded, and that it might keep some viewport settings";
+	"Tells the GUI that the whole PCB has changed. The \"revert\""
+	"parameter is deprecated but kept for compatibility and is ignored.";
 static fgw_error_t pcb_act_PCBChanged(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	const char *rv = NULL;
 	RND_ACT_IRES(0);
-	RND_ACT_MAY_CONVARG(1, FGW_STR, PCBChanged, rv = argv[1].val.str);
-	pcb_board_changed((rv != NULL) && (rnd_strcasecmp(rv, "revert") == 0));
+	pcb_board_replaced();
 	return 0;
 }
 
@@ -293,7 +288,7 @@ static const char pcb_acth_ImportGUI[] = "Asks user which schematics to import i
 static fgw_error_t pcb_act_ImportGUI(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	rnd_message(RND_MSG_ERROR, "The ImportGUI() action is deprecated. Using ImportSch() instead.\nFor details see: http://repo.hu/projects/pcb-rnd/help/err0002.html\n");
-	RND_ACT_IRES(rnd_actionva(RND_ACT_HIDLIB, "ImportSch", NULL));
+	RND_ACT_IRES(rnd_actionva(RND_ACT_DESIGN, "ImportSch", NULL));
 	return 0;
 }
 
