@@ -32,10 +32,10 @@
 
 #include "board.h"
 #include <librnd/core/actions.h>
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_dad_tree.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_dad_tree.h>
 #include <librnd/core/conf_hid.h>
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include "netlist.h"
 #include "event.h"
 
@@ -214,61 +214,62 @@ static void prop_pcb2dlg(propdlg_t *ctx)
 
 		hv.str = scope.array;
 		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wscope, &hv);
+		gds_uninit(&scope);
 	}
 }
 
-static void (*help_expose)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e) = NULL;
+static void (*help_expose)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e) = NULL;
 
-static void help_trace_thickness(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_trace_thickness(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/thickness.c"
 }
 
-static void help_trace_clearance(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_trace_clearance(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/clearance.c"
 }
 
-static void help_text_scale(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_text_scale(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/text_scale.c"
 }
 
-static void help_text_scale_x(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_text_scale_x(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/text_scale_x.c"
 }
 
-static void help_text_scale_y(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_text_scale_y(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/text_scale_y.c"
 }
 
-static void help_text_thickness(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_text_thickness(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/text_thickness.c"
 }
 
-static void help_text_rotation(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_text_rotation(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/text_rot.c"
 }
 
-static void help_arc_angles(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_arc_angles(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/arc_angles.c"
 }
 
-static void help_arc_r(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void help_arc_r(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 #	include "help/arc_r.c"
 }
 
-static void prop_nil_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void prop_nil_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 }
 
-static void prop_prv_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void prop_prv_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 	if (help_expose != NULL)
 		help_expose(attrib, prv, gc, e);
@@ -298,7 +299,7 @@ static void prop_valedit_update(propdlg_t *ctx, pcb_props_t *p, pcb_propval_t *p
 
 	memset(&hv, 0, sizeof(hv));
 	switch(p->type) {
-		case PCB_PROPT_STRING: hv.str = rnd_strdup(pv->string == NULL ? "" : pv->string); break;
+		case PCB_PROPT_STRING: hv.str = (pv->string == NULL ? "" : pv->string); break;
 		case PCB_PROPT_COORD:  hv.crd = pv->coord; break;
 		case PCB_PROPT_ANGLE:  hv.dbl = pv->angle; break;
 		case PCB_PROPT_DOUBLE: hv.dbl = pv->d; break;
@@ -369,7 +370,7 @@ static void prop_select_node_cb(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_
 	rnd_hid_tree_t *tree = attrib->wdata;
 	propdlg_t *ctx = tree->user_ctx;
 	pcb_props_t *p = NULL;
-	void (*last_help)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e) = NULL;
+	void (*last_help)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e) = NULL;
 	const char *helptxt = NULL;
 
 	last_help = help_expose;
@@ -741,8 +742,7 @@ static void pcb_dlg_propdlg(propdlg_t *ctx)
 
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-		RND_DAD_BEGIN_HPANE(ctx->dlg);
-			RND_DAD_SET_PANE_NAME(ctx->dlg, "left-right");
+		RND_DAD_BEGIN_HPANE(ctx->dlg, "left-right");
 
 			/* left: property tree and filter */
 			RND_DAD_BEGIN_VBOX(ctx->dlg);
@@ -835,7 +835,7 @@ fgw_error_t pcb_act_propedit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
-static void propdlg_unit_change(rnd_conf_native_t *cfg, int arr_idx)
+static void propdlg_unit_change(rnd_conf_native_t *cfg, int arr_idx, void *user_data)
 {
 	propdlg_t *ctx;
 	gdl_iterator_t it;
@@ -845,7 +845,7 @@ static void propdlg_unit_change(rnd_conf_native_t *cfg, int arr_idx)
 	}
 }
 
-static void propedit_brd_chg(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void propedit_brd_chg(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	propdlg_t *pd;
 	for(pd = gdl_first(&propdlgs); pd != NULL; pd = gdl_next(&propdlgs, pd))
@@ -853,7 +853,7 @@ static void propedit_brd_chg(rnd_hidlib_t *hidlib, void *user_data, int argc, rn
 			prop_refresh(pd);
 }
 
-static void propedit_brd_unload(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void propedit_brd_unload(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	propdlg_t *pd, *next;
 
@@ -878,7 +878,7 @@ void pcb_propdlg_init(void)
 	}
 
 	rnd_event_bind(PCB_EVENT_BOARD_EDITED, propedit_brd_chg, NULL, pcb_propedit_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, propedit_brd_unload, NULL, pcb_propedit_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, propedit_brd_unload, NULL, pcb_propedit_cookie);
 }
 
 void pcb_propdlg_uninit(void)
